@@ -48,11 +48,11 @@
 #' \deqn{ 
 #' \log \left( \frac{eps}{1-eps} \right) 
 #'    = \text{logit}(eps) 
-#'    = -0.405 + 2.867 \cdot IQ + 4.840 \times 10^4 \cdot N - 3.316 \times 10^3 \cdot I
+#'    = -0.405 + 2.867 \cdot IQ + 4.840 \times 10^{-4} \cdot N - 3.316 \times 10^{-3} \cdot I
 #'  }
 #'  Where \eqn{IQ} represents the question quality, calculated as the negative difference between the probability of an examinee 
 #'  with all attributes answering the question correctly and the probability of an examinee with no attributes answering the question correctly 
-#'  (\eqn{IQ = - \left\{ P\left( \boldsymbol{1} \right) - \left[ 1 - P\left( \boldsymbol{0} \right) \right] \right\}}), 
+#'  (\eqn{IQ = P\left( \boldsymbol{1} \right) - P\left( \boldsymbol{0} \right)}), 
 #'  and \eqn{N} and \eqn{I} represent the number of examinees and the number of questions, respectively.
 #' 
 #' 
@@ -703,6 +703,9 @@ check.validation <- function(Y, Q,
   if (search.method == "stepwise" && method != "Wald")
     stop("stepwise is for Wald method only!")
   
+  if (search.method == "forward" && method != "Wald")
+    stop("forward is for Wald method only!")
+  
   if (search.method == "beta" && method != "beta")
     stop("beta search method is for the beta method only!")
   
